@@ -44,6 +44,35 @@
 
 <dl>
 
+<dt><b>4.2.0</b> - <i>October 2018</i></dt>
+<dd>
+Added method wxSQLite3Database::GetKeySalt to access the key salt of encrypted databases<br>
+Fixed memory leaks in methods wxSQLite3ResultSet::GetExpandedSQL and wxSQLite3Statement::GetExpandedSQL<br>
+Adjusted encryption extension to support raw key (and salt) for the <b>ChaCha20 (sqleet)</b> encryption scheme<br>
+
+</dd>
+<dt><b>4.1.1</b> - <i>October 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.25.2<br>
+
+</dd>
+<dt><b>4.1.0</b> - <i>September 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.25.1<br>
+Added support for SQL window functions<br>
+Adjusted encryption extension to check for matching page sizes on rekeying a database<br>
+
+</dd>
+<dt><b>4.0.4</b> - <i>June 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.24.0<br>
+
+</dd>
+<dt><b>4.0.3</b> - <i>April 2018</i></dt>
+<dd>
+Adjusted encryption extension to better support the SQLite backup API<br>
+
+</dd>
 <dt><b>4.0.2</b> - <i>April 2018</i></dt>
 <dd>
 Upgrade to SQLite version 3.23.1<br>
